@@ -93,7 +93,7 @@ class Lightning(object):
         self.latitudes = positions[::3]
         self.longitudes = positions[1::3]
         times = positions[2::3]
-        self.times = np.array([dt.datetime.fromtimestamp(t) for t in times])
+        self.times = np.array([dt.datetime.utcfromtimestamp(t) for t in times])
 
         data = np.fromstring(self._xml.findtext(wfs.GML_DOUBLE_OR_NIL_REASON_TUPLE_LIST), dtype=float, sep=" ")
         fields = [f.attrib['name'] for f in self._xml.findall(wfs.SWE_FIELD)]
