@@ -49,7 +49,9 @@ SWE_DATA_RECORD = ".//{http://www.opengis.net/swe/2.0}DataRecord"
 SWE_FIELD = ".//{http://www.opengis.net/swe/2.0}field"
 SWE_LABEL = ".//{http://www.opengis.net/swe/2.0}label"
 SWE_UOM = ".//{http://www.opengis.net/swe/2.0}uom"
+WFS_ABSTRACT = ".//{http://www.opengis.net/wfs/2.0}Abstract"
 WFS_MEMBER = ".//{http://www.opengis.net/wfs/2.0}member"
+WFS_PARAMETER = ".//{http://www.opengis.net/wfs/2.0}Parameter"
 WFS_PARAMETER_NAME = ".//{http://xml.fmi.fi/schema/wfs/2.0}ParameterName"
 WFS_PARAMETER_VALUE = ".//{http://xml.fmi.fi/schema/wfs/2.0}ParameterValue"
 WFS_RETURN_FEATURE_TYPE = ".//{http://www.opengis.net/wfs/2.0}ReturnFeatureType"
